==> haskell-persistent-qq-2.9.1-61-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-qq
version: 2.9.1
id: persistent-qq-2.9.1-9IxWTgwiGK83gHLVSL95Mt
key: persistent-qq-2.9.1-9IxWTgwiGK83gHLVSL95Mt
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
homepage: https://github.com/yesodweb/persistent#readme
synopsis: Provides a quasi-quoter for raw SQL for persistent
description:
    Please see README and API docs at <http://www.stackage.org/package/persistent>.
category: Database, Yesod
abi: c96d0a6b1de06acad80ed5be86a170d6
exposed: True
exposed-modules:
    Database.Persist.Sql.Raw.QQ
hidden-modules: Paths_persistent_qq
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-qq-2.9.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-qq-2.9.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-qq-2.9.1
hs-libraries: HSpersistent-qq-2.9.1-9IxWTgwiGK83gHLVSL95Mt
depends:
    base-4.12.0.0 haskell-src-meta-0.8.2-KZb3g4f7nfRCqb0JV0UdRL
    mtl-2.2.2 persistent-2.10.1-3og9MAC29gi7KTjTVnXGs7
    template-haskell-2.14.0.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-persistent-qq/html/persistent-qq.haddock
haddock-html: /usr/share/doc/haskell-persistent-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-qq-2.9.1-62-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-qq
version: 2.9.1
id: persistent-qq-2.9.1-2AZG2fFWzoCQDIvOCdv0J
key: persistent-qq-2.9.1-2AZG2fFWzoCQDIvOCdv0J
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
homepage: https://github.com/yesodweb/persistent#readme
synopsis: Provides a quasi-quoter for raw SQL for persistent
description:
    Please see README and API docs at <http://www.stackage.org/package/persistent>.
category: Database, Yesod
abi: 704851a6a0286e6f6a89823c2e35ec9b
exposed: True
exposed-modules:
    Database.Persist.Sql.Raw.QQ
hidden-modules: Paths_persistent_qq
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-qq-2.9.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-qq-2.9.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-qq-2.9.1
hs-libraries: HSpersistent-qq-2.9.1-2AZG2fFWzoCQDIvOCdv0J
depends:
    base-4.12.0.0 haskell-src-meta-0.8.2-KZb3g4f7nfRCqb0JV0UdRL
    mtl-2.2.2 persistent-2.10.1-BsiVA8EaffVF5nNTPbHD98
    template-haskell-2.14.0.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-persistent-qq/html/persistent-qq.haddock
haddock-html: /usr/share/doc/haskell-persistent-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
